/// <reference types="node" />
import { Redis, RedisOptions, RedisKey, RedisValue } from 'ioredis';
export declare class RedisService {
    constructor(client: Redis, options: RedisOptions);
    /** Redis 客户端 */
    readonly client: Redis;
    /** Redis 客户端配置信息 */
    readonly options: RedisOptions;
    /** 分布式锁 key-value map */
    private readonly lockMap;
    /**
     * 从Redis中取出数据
     * @param key 键
     */
    get<T>(key: RedisKey): Promise<T>;
    /**
     * 向Redis中存储数据（无过期时间）
     * @param key 键
     * @param value 值
     * @returns 存储结果
     */
    set(key: RedisKey, value: RedisValue): Promise<boolean>;
    /**
     * 向Redis中存储数据（过期时间以秒计）
     * @param key 键
     * @param value 值
     * @param seconds 过期时间，单位：秒
     * @returns 存储结果
     */
    setex(key: RedisKey, value: RedisValue, seconds: number): Promise<boolean>;
    /**
     * 向Redis中存储数据（过期时间以毫秒计）
     * @param key 键
     * @param value 值
     * @param milliseconds 过期时间，单位：毫秒
     * @returns 存储结果
     */
    psetex(key: RedisKey, value: RedisValue, milliseconds: number): Promise<boolean>;
    /**
     * 查看key列表，支持通配符
     * @param pattern key匹配模式，支持通配符，例如：*set*
     * @returns 匹配到的key列表
     */
    keys(pattern: string): Promise<string[]>;
    /**
     * 值自增
     * @param key 键
     * @returns 自增后的结果
     */
    incr(key: RedisKey): Promise<number>;
    /**
     * 往散列中存储键值对
     * @description 如果散列中没有这个字段，插入成功，返回true。如果有这个字段，插入失败，返回false
     * @param key 散列key
     * @param field 散列字段
     * @param value 散列字段值
     * @returns 存储结果
     */
    hsetnx(key: RedisKey, field: string, value: RedisValue): Promise<boolean>;
    /**
     * 往散列中存储键值对（覆盖方式）
     * @param key 散列key
     * @param field 散列字段
     * @param value 散列字段值
     * @returns 存储结果
     */
    hmset(key: RedisKey, field: string, value: RedisValue): Promise<boolean>;
    /**
     * 往散列中存储键值对（覆盖方式），支持过期时间
     * @param key 散列key
     * @param field 散列字段
     * @param value 散列字段值
     * @param seconds 过期时间，单位：秒
     * @returns 存储结果
     */
    hmsetex(key: RedisKey, field: string, value: RedisValue, seconds: number): Promise<boolean>;
    /**
     * 获取散列中指定字段的数据
     * @param key 散列key
     * @param field 散列字段
     * @returns 散列中key所对应的数据
     */
    hget<T>(key: RedisKey, field: string): Promise<T>;
    /**
     * 获取散列数据
     * @param key 散列key
     * @returns 散列数据
     */
    hgetall(key: RedisKey): Promise<Record<string, string>>;
    /**
     * 从散列中删除键值对
     * @param key 散列key
     * @param field 散列字段
     * @returns 删除结果
     */
    hdel(key: RedisKey, field: string): Promise<boolean>;
    /**
     * 往列表中插入元素
     * @param key 列表key
     * @param value 元素值
     * @returns 列表中节点数量
     */
    rpush(key: RedisKey, value: RedisValue): Promise<number>;
    /**
     * 从Redis中取出List数据
     * @param key 键
     * @returns 列表数据
     */
    getList<T>(key: RedisKey): Promise<T[]>;
    /**
     * 往集合中插入元素
     * @param key 键
     * @param members 元素
     * @returns 插入的元素数量，如果集合中已经有了这个元素，重新插入的元素不计数
     */
    sadd(key: RedisKey, ...members: (string | Buffer | number)[]): Promise<number>;
    /**
     * 从集合中删除元素
     * @param key 集合键
     * @param members 元素列表
     * @returns 删除的元素个数
     */
    srem(key: RedisKey, ...members: (string | Buffer | number)[]): Promise<number>;
    /**
     * 判断集合中是否有此元素
     * @param key 键
     * @param member 元素
     * @returns 0 | 1
     */
    sismember(key: RedisKey, member: string | number | Buffer): Promise<number>;
    /**
     * 从一个集合中移动元素到另一个集合
     * @param source 原集合
     * @param destination 目标集合
     * @param member 元素
     * @returns 0|1 表示移动成功与否
     */
    smove(source: RedisKey, destination: RedisKey, member: string | number | Buffer): Promise<number>;
    /**
     * 获取集合
     * @param key 集合键
     * @returns 集合
     */
    getSet<T>(key: RedisKey): Promise<Set<T>>;
    /**
     * 删除redis中的记录
     * @param key 要删除的key
     * @returns 删除结果
     */
    delete(key: string): Promise<boolean>;
    /**
     * 设置键的过期时间
     * @param key 键
     * @param seconds 过期时间，单位：秒
     * @returns 设置成功与否
     */
    expire(key: string, seconds: number): Promise<boolean>;
    /**
     * 获取锁
     * @param lock 锁key
     * @param expire 过期时间，单位：毫秒
     * @returns 锁获取结果
     */
    getLock(lock: RedisKey, expire: number): Promise<boolean>;
    /**
     * 释放锁
     * @param lock 锁key
     * @returns 释放结果
     */
    releaseLock(lock: RedisKey): Promise<boolean>;
}
